<h1>Platypy - A python module</h1>
This module has a new  feature called <strong>coolcalci.</strong> This coolcalci sub module
will help you to do arithmetic operations very fast and if you want this colcalci as an 
different module you can install it by the give link : 
<a href="https://pypi.org/project/Coolcalci/">https://pypi.org/project/Coolcalci/</a>
and if you want install it by cmd (command prompt) you can type this command:

<code><strong> pip install Coolcalci </strong></code>

and to import it in platypy so you have to type first to install it :

<code><strong> pip install platypy </strong></code>

to import it in your project type this : 

><strong>import platypy</strong>
>
><strong>from platypy.coolcalci import *</strong>
# To add something from coolcalci
to add something:
><strong>from platypy.coolcalci import *</strong>
> 
><strong>res = add(1 + 2)</strong>
> 
><strong>print(res)</strong>

<h1>To create questions</h1>
This submodule <code><strong>createquestionsandanswers</strong></code> will help you to create quiz and make questions
very fast because people would sometimes make many questions in 50 lines of code but this submodule will take 1 line and 
to install it type this command:
<br>
<code><strong>Pip install platyquest</strong></code>
to import it in your project:

><strong>from platyquest import *</strong>
> 
> <strong>from platypy.createquestionsandanswers import * // to import it from platypy 
> 
> ###### its not a copyright as it is created by me platyquest and platypy.createquestionsandanswers</strong>
you can create quiz by this command:
><strong>createquiz() <-- fill the important requirements </strong>

for creating a single question:
> <strong>question() <-- fill the requirements</strong>

# To Change the font of alphabhet
From this package in platypy you can change the font of alphabhets. The name of this pakage is <code><strong>Fontschanger</strong></code> you can install it from cmd (Command prompt) <code><strong>Pip install platypy.Fontschanger</strong></code> or you can:
>Pip install Fontsfort
>###### This isn't a copyright as you can see the username of module owner is same
To Use this package you have to type the basic command:
><code><strong>from platypy.Fontschanger</strong></code>
> 
> fontchange(Alphabhet='<input>')          <-- Fill the requirements

Other commands you can learn on my channel : 
<br>
<a href = "https://www.youtube.com/channel/UCsP5fIAdguQF0muRke5J3zg">https://www.youtube.com/channel/UCsP5fIAdguQF0muRke5J3zg</a>